==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Het is niet mogelijk om het vorige spel te starten. Een nieuw spel wordt gestart</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 verstreken</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 genomen stappen</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 van %2 doelen zijn nog over</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Gepauzeerd</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Commando</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Controle</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Optie</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecteer applicatie taal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;systeemtaal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notitie</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart de applicatie om de taalwijziging door te voeren</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nieuw spel</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jaag en dood</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursieve routevinder</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Opslagplaats</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Opslagplaats 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Opslagplaats 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Opslagplaats 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Opslagplaats 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algorithme</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Doelen:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Grootte:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jaag en dood</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursieve routevinder</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Opslagplaats </translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Opslagplaats 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Opslagplaats 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Opslagplaats 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Opslagplaats 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>CuteMaze Scores</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Stappen</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algorithme</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gefeliciteerd</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>De score is goed genoeg voor de top 10
Geef je naam in:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Spel</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Laat zien waar je geweest bent</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Laat het aantal stappen zien</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Laat de verlopen tijd zien</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Gladde beweging</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Besturing</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Omhoog</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Naar beneden</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Naar links</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Naar rechts</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Schakel flag</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Thema</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Selecteer thema bestand</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Aanmaken data folder faalde</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Kopiëren thema bestand faalde</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Verwijder het geselecteerde thema</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Verwijderen thema faalde</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Toon</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzeer</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Hint</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Hoogste &amp;scores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Stoppen</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Inzoomen</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uitzoomen</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Applicatietaal</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Voorkeuren</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Een &apos;top-down&apos; doolhof spel</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onder de &lt;a href=%1&gt;GPL 3&lt;/a&gt; licentie</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Iconen zijn van het &lt;a href=%1&gt;Oxygen&lt;/a&gt; thema</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Gebruikt onder de &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licentie</translation>
    </message>
</context>
</TS>

==> cutemaze_1.2.6.orig.tar.gz: cutemaze-1.2.6/translations/cutemaze_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Het vorige spel kan niet worden gestart; er zal een nieuw spel worden gestart.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 verstreken</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 genomen stappen</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 van %2 resterende doelen</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Gepauzeerd</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Opdracht</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Besturing</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Optie</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecteer de applicatietaal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart de applicatie om de taalwijziging toe te passen.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nieuw spel</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jaag en vermoord</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursieve routevinder</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Opslagplaats</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Opslagplaats 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Opslagplaats 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Opslagplaats 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Opslagplaats 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritme:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Doelen:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Grootte:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jaag en vermoord</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursieve routevinder</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Opslagplaats </translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Opslagplaats 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Opslagplaats 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Opslagplaats 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Opslagplaats 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>CuteMaze-scores</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Stappen</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritme</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gefeliciteerd!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Je score is goed genoeg voor de top 10.
Voer je naam in:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Spel</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Laat zien waar je geweest bent</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Laat het aantal stappen zien</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Laat de verstreken tijd zien</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Vloeiend verplaatsen</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Besturing</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Omhoog verplaatsen:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Omlaag verplaatsen:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Naar links verplaatsen:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Naar rechts verplaatsen:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Schakel flag:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Thema&apos;s</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Selecteer themabestand</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Het creëren van de gegevensmap is mislukt.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Het kopiëren van het themabestand is mislukt.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Geselecteerd thema verwijderen?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Het verwijderen van het thema is mislukt.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>Hint weergeven:</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Beeld</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzeren</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Hint</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Top&amp;scores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Inzoomen</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uitzoomen</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>In&amp;stellingen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Applicatietaa&amp;l...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Voorkeuren...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Een &apos;top-down&apos; doolhofspel</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onder de &lt;a href=%1&gt;GPL 3&lt;/a&gt;-licentie</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>De pictogrammen zijn afkomstig uit het &lt;a href=%1&gt;Oxygen&lt;/a&gt;-thema</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Gebruikt onder de &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licentie</translation>
    </message>
</context>
</TS>
